@@ -1,22 +1,20 @@
 import numpy as np
 from .element_counts import element_counts
-def nominal_oxidation_state(formula_list):
-    
+def nominal_oxidation_state(msTuple):
     """ 
 	Docstring for function pyKrev.nominal_oxidation_state
 	====================
-	This function takes a list of molecular formula strings and returns the nominal oxidatate state of C.
+	This function takes an msTuple and returns the nominal oxidatate state of C.
     
 	Use
 	----
 	nominal_oxidation_state(Y)
     
-	Returns a numpy array of len(Y) in which each item is the nominal oxidation state of C.  
+	Returns a numpy array of len(Y[0]) in which each item, i, is the nominal oxidation state of C corresponding to Y[0][i].  
     
 	Parameters
 	----------
-	Y: A list of molecular formula strings. 
-    
+	Y: msTuple
     
 	Info
 	----------
@@ -24,7 +22,7 @@ def nominal_oxidation_state(formula_list):
 	"NOSC allows for computation of the average carbon oxidation state of an organic compound without writing out the oxidation half reaction."
 	"Degradation of natural organic matter: a thermodynamic analysis." 
 	Geochimica et Cosmochimica Acta 75.8 (2011): 2030-2042.       
-	
+
 	NOSC = -((-Z + 4a + b - 3c - 2d + 5e - 2f)/a) + 4 
 	where Z = charge and 
 	a = C
@@ -35,11 +33,10 @@ def nominal_oxidation_state(formula_list):
  	f = S
         
     """      
-    count_list = element_counts(formula_list)
-    
+	#Setup
+    count_list = element_counts(msTuple)
     NOSCs = np.array([])
-        
+    #Main
     for i in count_list:
         NOSCs = np.append(NOSCs,-((4*i['C'] + i['H'] - 3 * i['N'] - 2 * i['O'] + 5 * i['P'] - 2 * i['S'])/i['C']) + 4) 
-    
     return NOSCs
\ No newline at end of file
