@@ -1,16 +1,15 @@
-from ..diversity import compound_class
+from ..diversity.compound_class import compound_class
 from matplotlib import pyplot as plt
 import pandas as pd
 import numpy as np
 
-def compound_class_plot(formula_list,
-                        mass_list = [],
+def compound_class_plot(msTuple,
                         method = 'MSCC',
                         **kwargs):
     """ 
 	Docstring for function PyKrev.compound_class_plot
 	====================
-	This function takes a list of molecular formula strings and plots a bar chart of the compound classes present.  
+	This function takes an mStuple and plots a bar chart of the compound classes present.  
     
 	Use
 	----
@@ -20,13 +19,12 @@ def compound_class_plot(formula_list,
     
 	Parameters
 	----------
-	Y: A list of molecular formula strings.
+	Y: msTuple
     mass_list: a list of mz values to pass to pk.compound_class -> required for the MSCC algorithm.
 	method: the element to determine the atomic class. One of: C,H,N,O,S or P.
     **kwargs: key word arguments to plt.bar
-    
     """
-    compoundClass, cclassCounts = compound_class(formula_list,mass_list,method = method)
+    compoundClass, cclassCounts = compound_class(msTuple,method = method)
     labels = []
     values = []
     for c in cclassCounts:      
